@@ -2,10 +2,9 @@ import re
 from re import RegexFlag
 from typing import List, Optional
 
-from build_helpers import ADDITIONAL_DEFINITIONS
 from build_pymeos_functions_modifiers import period_shift_tscale_modifier, cstring2text_modifier, text2cstring_modifier, \
     timestampset_make_modifier, gserialized_from_lwgeom_modifier, tpointseq_make_coords_modifier
-from pymeos_cffi.builder.objects import conversion_map, Conversion
+from objects import conversion_map, Conversion
 
 
 class Parameter:
@@ -37,7 +36,7 @@ class Parameter:
             return None
         conversion = self.cp_conversion
         if nullable:
-            conversion += f' if {self.name} else _ffi.NULL'
+            conversion += f' if {self.name} is not None else _ffi.NULL'
         return conversion
 
     def __str__(self) -> str:
@@ -100,7 +99,7 @@ def lwpoint_to_shapely_point(lwpoint: Any) -> spg.Point:
 
 """
 
-manual_functions = {
+function_notes = {
 }
 
 function_modifiers = {
@@ -137,12 +136,16 @@ nullable_parameters = {
     ('temporal_as_mfjson', 'srs'),
     ('period_shift_tscale', 'duration'),
     ('period_shift_tscale', 'start'),
+    ('period_shift_tscale', 'start'),
     ('timestampset_shift_tscale', 'start'),
     ('timestampset_shift_tscale', 'duration'),
+    ('timestampset_shift_tscale', 'start'),
     ('periodset_shift_tscale', 'start'),
     ('periodset_shift_tscale', 'duration'),
+    ('periodset_shift_tscale', 'start'),
     ('temporal_shift_tscale', 'start'),
     ('temporal_shift_tscale', 'duration'),
+    ('temporal_shift_tscale', 'shift'),
     ('tbox_make', 'p'),
     ('tbox_make', 's'),
     ('stbox_make', 'p'),
@@ -172,20 +175,22 @@ def is_output_parameter(function: str, parameter: Parameter) -> bool:
 
 
 def main():
-    with open('/usr/local/include/meos.h') as f:
+    with open('pymeos_cffi/builder/meos.h') as f:
         content = f.read()
-        content = content.replace('#', '//#')
-        content = content.replace(*ADDITIONAL_DEFINITIONS)
-        # Remove comments
-        content = re.sub(r'//.*', '', content)
-        content = re.sub(r'/\*.*?\*/', '', content, flags=RegexFlag.MULTILINE)
+    # Regex lines:
+    # 1st line: Match beginning of function with optional "extern", "static" and "inline"
+    # 2nd line: Match the return type as any alphanumeric string with optional "const" modifier (before the type) or
+    #             pointer modifier (after the type)
+    # 3rd line: Match the name of the function as any alphanumeric string
+    # 4th line: Match the parameters as any sequence of alphanumeric characters, commas, spaces and asterisks between
+    #             parenthesis and end with a semicolon. (Parameter decomposition will be performed later)
     f_regex = r'(?:extern )?(?:static )?(?:inline )?' \
               r'(?P<returnType>(?:const )?\w+(?: \*+)?)' \
               r'\s*(?P<function>\w+)' \
               r'\((?P<params>[\w\s,\*]*)\);'
     matches = re.finditer(f_regex, ''.join(content.splitlines()), flags=RegexFlag.MULTILINE)
 
-    with open('../functions.py', 'w+') as file:
+    with open('pymeos_cffi/functions.py', 'w+') as file:
         file.write(BASE)
         for match in matches:
             named = match.groupdict()
@@ -355,10 +360,10 @@ def build_function_string(function_name: str, return_type: ReturnType, parameter
     if len(param_conversions) > 0:
         param_conversions = f'    {param_conversions}\n'
 
-    # Add TO DO note if the function is listed in the manual_functions dictionary
+    # Add TO DO note if the function is listed in the function_notes dictionary
     note = ''
-    if function_name in manual_functions:
-        note = f'#TODO {manual_functions[function_name]}\n'
+    if function_name in function_notes:
+        note = f'#TODO {function_notes[function_name]}\n'
 
     # Create common part of function string (note, name, parameters, return type and parameter conversions).
     base = f'{note}def {function_name}({params}) -> {function_return_type}:\n' \
